﻿using MindFusion.Diagramming.Wpf;
using System.Globalization;
using System.Windows;
using System.Windows.Media;

namespace MindfusionDemo.Items
{
    /// <summary>
    /// Diagram node that draw the text.
    /// </summary>
    internal class TextDiagramItem : DiagramNode
    {
        private readonly string text;
        private readonly Point textDrawPoint;

        private readonly FlowDirection flowDirection = FlowDirection.LeftToRight;
        private readonly Typeface typeface = new Typeface(new FontFamily("Heebo"), new FontStyle(), new FontWeight(), new FontStretch());
        private readonly double fontSize = 36;
        private readonly Brush foreground = Brushes.Blue;

        /// <summary>
        /// Constructor.
        /// </summary>
        /// <param name="text">Text to draw.</param>
        /// <param name="textDrawPoint">Text draw point.</param>
        public TextDiagramItem(string text, Point textDrawPoint)
        {
            this.text = text;
            this.textDrawPoint = textDrawPoint;

            // See resulting svg <text> and its attributes.
            // Not expected result.
            FontSize = fontSize;
            FontFamily = new FontFamily("Heebo");
        }

        /// <inheritdoc/>
        public override void Draw(DrawingContext graphics, MindFusion.Diagramming.Wpf.RenderOptions options)
        {
            var formattedText = new FormattedText(text, CultureInfo.CurrentCulture, flowDirection, typeface, fontSize, foreground);
            graphics.DrawText(formattedText, textDrawPoint);
        }
    }
}
